import math


class Dot:
    x: int
    y: int

    def __init__(self, x, y):
        self.x = x
        self.y = y

    def trans_to(self, x, y):
        self.x = x
        self.y = y

    def trans_by(self, x, y):
        self.x += x
        self.y += y


def get_len_sqr(d1: Dot, d2: Dot) -> int:
    return (d1.x - d2.x) ** 2 + (d1.y - d2.y) ** 2


last_index = 0


class Triangle:
    d1: Dot
    d2: Dot
    d3: Dot
    cos_1: float
    cos_2: float
    cos_3: float
    len_12s: int
    len_23s: int
    len_13s: int
    index: int

    def __init__(self, d1: Dot, d2: Dot, d3: Dot):
        global last_index
        last_index += 1
        self.index = last_index
        self.d1 = d1
        self.d2 = d2
        self.d3 = d3
        self.len_12s = get_len_sqr(d1, d2)
        self.len_23s = get_len_sqr(d2, d3)
        self.len_13s = get_len_sqr(d1, d3)
        self.cos_1 = count_cos(self.len_12s, self.len_13s, self.len_23s)
        self.cos_2 = count_cos(self.len_12s, self.len_23s, self.len_13s)
        self.cos_3 = count_cos(self.len_13s, self.len_23s, self.len_12s)

    def trans_to(self, dot_ind: int, x: int, y: int):
        dot = self.d1
        if dot_ind == 1:
            dot = self.d1
        elif dot_ind == 2:
            dot = self.d2
        elif dot_ind == 3:
            dot = self.d3
        initial_x = dot.x
        initial_y = dot.y
        delta_x = x - initial_x
        delta_y = y - initial_y
        self.d1.trans_by(delta_x, delta_y)
        self.d2.trans_by(delta_x, delta_y)
        self.d3.trans_by(delta_x, delta_y)

    def rotate(self):
        self.d1, self.d2, self.d3 = self.d2, self.d3, self.d1
        self.len_12s, self.len_23s, self.len_13s = self.len_23s, self.len_13s, self.len_12s
        self.cos_1, self.cos_2, self.cos_3 = self.cos_2, self.cos_3, self.cos_1


def is_dots_on_line(d1: Dot, d2: Dot, d3: Dot) -> bool:
    return (d2.y - d1.y) / (d2.x - d1.x) == (d3.y - d1.y) / (d3.x - d1.x)


def make_triangle(x1, y1, x2, y2, x3, y3) -> Triangle:
    return Triangle(Dot(x1, y1), Dot(x2, y2), Dot(x3, y3))


def has_len(triangle: Triangle, side_len: int):
    lens = [triangle.len_12s, triangle.len_13s, triangle.len_23s]
    return side_len in lens


def count_cos(asq: int, bsq: int, csq: int) -> float:
    # c**2 = a**2 + b**2 - 2*a*b * cos
    # c**2 - (a**2 + b**2_ = - 2*a*b * cos
    # (c**2 - a**2 - b**2) / (- 2*a*b ) = cos
    # cos = (c**2 - a**2 - b**2) / (- 2*a*b )
    a = asq ** 0.5
    b = bsq ** 0.5
    # print(a, b, c)
    cos = (csq - asq - bsq) / (- 2 * a * b)
    # print(cos)
    return cos


def count_angle(cos: float) -> float:
    return math.acos(cos)


def check_angles_eq_180(a1: float, a2: float, a3: float) -> bool:
    # print(a1, a2, a3)
    # print(a1 + a2 + a3)
    return round((a1 + a2 + a3) * 1000000) / 1000000 == round(math.pi * 1000000) / 1000000


def checks_coses_eq_180(c1: float, c2: float, c3: float) -> bool:
    # print(c1, c2, c3, math.pi)
    return check_angles_eq_180(*[count_angle(i) for i in [c1, c2, c3]])


def perform_check_triangles(center_triangle: Triangle, triangle12: Triangle, triangle23: Triangle,
                            triangle13: Triangle) -> bool:
    if center_triangle.len_12s == triangle12.len_12s:
        if center_triangle.len_23s == triangle23.len_12s:
            # print('hhihih')
            # print(center_triangle.len_13s, triangle13.len_12s, triangle13.len_23s,triangle13.len_23s,)
            if center_triangle.len_13s == triangle13.len_12s:
                if checks_coses_eq_180(center_triangle.cos_1, triangle12.cos_2, triangle13.cos_1):
                    if checks_coses_eq_180(center_triangle.cos_2, triangle12.cos_1, triangle23.cos_2):
                        if checks_coses_eq_180(center_triangle.cos_3, triangle13.cos_2, triangle23.cos_1):
                            return True
    return False


def check_triangles(center_triangle: Triangle, triangle12: Triangle, triangle23: Triangle,
                    triangle13: Triangle) -> bool:
    for t1_rotate in range(3):
        for t2_rotate in range(3):
            for t3_rotate in range(3):
                res = perform_check_triangles(center_triangle, triangle12, triangle23, triangle13)
                if res:
                    return True
                triangle13.rotate()
            triangle23.rotate()
        triangle12.rotate()
    return False


def main():
    t = int(input())
    n = int(input())
    ans = 0
    triangles = []
    results = set()
    for i in range(n):
        triangle = make_triangle(*[int(i) for i in input().split()])
        triangles.append(triangle)
    # for i in triangles:
        # print(i.index, i.len_12s, i.len_23s, i.len_13s)
    for center_triangle in triangles:
        # if center_triangle.index != 2:
        #     continue
        for triangle12 in filter(lambda tr: has_len(tr, center_triangle.len_12s), triangles):
            for triangle23 in filter(lambda tr: has_len(tr, center_triangle.len_23s), triangles):
                if triangle23 == triangle12:
                    continue
                for triangle13 in filter(lambda tr: has_len(tr, center_triangle.len_13s), triangles):
                    if triangle13 == triangle12 or triangle13 == triangle23:
                        continue
                    if center_triangle in [triangle12, triangle23, triangle13]:
                        continue
                    trs = [center_triangle.index, triangle12.index, triangle23.index, triangle13.index]
                    trs.sort()
                    trs_s = ' '.join((str(i) for i in trs))
                    if trs_s in results:
                        continue
                    # print(center_triangle, triangle12, triangle23, triangle13)
                    res = check_triangles(center_triangle, triangle12, triangle23, triangle13)
                    if res:
                        results.add(trs_s)
                        # print(center_triangle.index, triangle12.index, triangle23.index, triangle13.index)
                        ans += res
    print(len(results))
    for i in results:
        print(i)


main()